Stan Math Library: stan/math/prim/mat/fun/csr_u_to_z.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
csr_u_to_z.hpp File Reference
`#include <stan/math/prim/mat/err/check_range.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
int | stan::math::csr_u_to_z (const std::vector< int > &u, int i)
| Return the z vector computed from the specified u vector at the index for the z vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.